<?php

namespace FiloBlu\ExtAmastyGeoipRedirect\Controller\Index;


class Landing extends \Magento\Framework\App\Action\Action {

    /** @var \Magento\Framework\View\Result\PageFactory */
    protected $resultPageFactory;
    protected $_helper;
    protected $layoutFactory;
    protected $storeManager;
    protected $scopeConfig;

    public function __construct(
    \Magento\Framework\App\Action\Context $context,
    \Magento\Store\Model\StoreManagerInterface $storeManager,
    \Magento\Framework\View\Result\PageFactory $resultPageFactory,
    \FiloBlu\Newsletter\Helper\Data $helper,
    \Magento\Framework\View\Page\Config $layoutFactory,
    \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig
    ) {
        $this->storeManager = $storeManager;
        $this->resultPageFactory = $resultPageFactory;
        $this->_helper = $helper;
        $this->layoutFactory = $layoutFactory;
        $this->scopeConfig = $scopeConfig;

        parent::__construct($context);
    }

    public function execute() {

        $currentStoreId = $this->storeManager->getStore()->getId();

        if (!$this->scopeConfig->getValue('amgeoipredirect/general/enable', \Magento\Store\Model\ScopeInterface::SCOPE_STORES, $currentStoreId) ||
            !$this->scopeConfig->getValue('amgeoipredirect/landing/enable_landing', \Magento\Store\Model\ScopeInterface::SCOPE_STORES, $currentStoreId)) {
            return null;
        }

        $this->layoutFactory->setRobots($this->scopeConfig->getValue('amgeoipredirect/landing/landing_robots', \Magento\Store\Model\ScopeInterface::SCOPE_STORES, $currentStoreId));
        $resultPage = $this->resultPageFactory->create();
        $this->getResponse()->setNoCacheHeaders();
        $resultPage->getConfig()->getTitle()->set($this->scopeConfig->getValue('amgeoipredirect/landing/landing_title', \Magento\Store\Model\ScopeInterface::SCOPE_STORES, $currentStoreId));
        $resultPage->getConfig()->setDescription($this->scopeConfig->getValue('amgeoipredirect/landing/landing_description', \Magento\Store\Model\ScopeInterface::SCOPE_STORES, $currentStoreId));

        $hreflangs = unserialize($this->scopeConfig->getValue('amgeoipredirect/landing/hreflang', \Magento\Store\Model\ScopeInterface::SCOPE_STORES, $currentStoreId));

        if ($hreflangs && count($hreflangs)) {
            foreach ($hreflangs as $hreflang) {

                $resultPage->getConfig()->addRemotePageAsset(
                    $hreflang["href"],
                    'alternate',
                    ['attributes' => ['rel' => 'alternate', 'hreflang' => $hreflang["hreflang"]]]
                );
            }
        }

        return $resultPage;

    }

}
